@@ -107,12 +107,14 @@ class Canvas(HasTraits):
         if not particles:
             particles = ParticleManager()
         self._particles = particles
-
-        # Set bg before resolution
-        self._resolution = BGRES
-        if background is None:
+            
+        if background is None and rez is None:
             self.reset_background() #sets default color/resolution    
+        elif background is not None and rez is None:
+            self._resolution = BGRES
+            self.set_bg(background, keepres=False, inplace=True)
         else:
+            self._resolution = rez
             self.set_bg(background, keepres=rez, inplace=True) 
             
         if not grid:
@@ -140,7 +142,10 @@ class Canvas(HasTraits):
         
     @property
     def threshfcn(self):
-        return self._threshtype
+        try:
+            return self._threshtype
+        except CanvasAttributeError:
+            return None
     
     @threshfcn.setter
     def threshfcn(self):
@@ -148,7 +153,12 @@ class Canvas(HasTraits):
                                    '**kwargs)" to set the binary function.')
 
     # Public Methods
-    # -------------              
+    # -------------      
+    def add(self, particle, *args, **kwargs):
+        """ Can't rely on __getattr__ because want *args to pass; only
+        kwargs pass correctly; and wrapper was more pain than worth. """
+        return self._particles.add(particle, *args, **kwargs)
+    
     def reset_background(self):
         """ Restore default background image; restores default RES, redraws
             particles over it."""
@@ -160,10 +170,8 @@ class Canvas(HasTraits):
                 
     def reset_grid(self):
         """ New grid of default x/y spacing; rez is optional """
-        xs = ys = 0
-        xe, ye = self.rez
-        self.grid = CartesianGrid(ystart=ys, xstart=xs, yend=xe, xend=ye,
-                              xspacing=GRIDYSPACE, yspacing = GRIDXSPACE)
+        self.grid = CartesianGrid(rez=self.rez, negative_y=True,
+                              xspacing=GRIDYSPACE, yspacing=GRIDXSPACE)
         
 
     def clear_canvas(self):
@@ -193,6 +201,19 @@ class Canvas(HasTraits):
             return cout    
 
 
+    def of_ptypes(self, *types, **kwargs):
+        """ Retain only particles pertaining to specified *types; 
+        optionally inplace."""
+
+        inplace = kwargs.pop('inplace', False)
+        if inplace:
+            self._particles.of_ptypes(*types)
+        else:
+            cout = Canvas.copy(self)
+            cout._particles.of_ptypes(*types)
+            return cout
+
+
     def pixelmap(self, fcn, axis=0, *fcnargs, **fcnkwargs):
         """ Image mapper (np.apply_along_axis)
 
@@ -278,6 +299,7 @@ class Canvas(HasTraits):
             if bgout is not None:
                 cout.background = bgout
             return cout
+        
 
     def patchshow(self, *args, **kwargs):
         """ ...
@@ -292,6 +314,7 @@ class Canvas(HasTraits):
         
         title = kwargs.pop('title', None)        
         bgonly = kwargs.pop('bgonly', False)
+        annotate = kwargs.pop('annotate', False)
 
         grid = kwargs.pop('grid', False)
         gcolor = kwargs.pop('gcolor', None)
@@ -337,7 +360,6 @@ class Canvas(HasTraits):
 
         if cmap:
             bg = self.graybackground
-
         else:
             bg = self.background
             
@@ -385,16 +407,40 @@ class Canvas(HasTraits):
                     axes.add_collection(self.grid.as_patch(
                         edgecolors=gcolor, linestyles=gstyle))    
         
-        if title:
-            axes.set_title(title)        
-
+        axes = self._annotate_plot(axes, annotate, title)    
+        
         if save:
             path = _parse_path(save)
             plt.savefig(path, dpi=dpi, bbox_inches=bbox_inches)
-        
-        return axes 
+        return axes
 
 
+    def _annotate_plot(self, axes, annotate, title):
+        """ Hacky boiler plat reduction.  show() and patchshow() both do exact
+        same thing at end; didn't want to put it twice."""
+        if annotate:
+            axes.set_xlabel('px')
+            axes.set_ylabel('px')
+            if not title:
+                if len(self._particles) == 1:
+                    pcnt_str = '1 particle'
+                else:
+                    pcnt_str = '%s particles' % len(self._particles)
+
+                if len(self._particles.ptypes) == 1:
+                    ptype_str = '%s' % self._particles.ptypes[0]
+                else:
+                    ptype_str = '%s types' % len(self._particles.ptypes)
+                    
+                title = '%s (%s)    %.2f%% coverage' % \
+                    (pcnt_str, ptype_str, 100.0*self.pixarea)
+            
+        if title:
+            axes.set_title(title)                    
+            
+        return axes         
+        
+
     #http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.imshow
     def show(self, *args, **kwargs):
         """ Wrapper to imshow.  Converts to gray to allow color maps.
@@ -411,6 +457,7 @@ class Canvas(HasTraits):
         title = kwargs.pop('title', None)
         save = kwargs.pop('save', None)
         bgonly = kwargs.pop('bgonly', False)
+        annotate = kwargs.pop('annotate', False)
         
         grid = kwargs.pop('grid', False)
         gcolor = kwargs.pop('gcolor', None)
@@ -487,16 +534,13 @@ class Canvas(HasTraits):
             axes.imshow(image, **kwargs)
         else:     
             axes = plt.imshow(image, **kwargs).axes        
-
-        if title:
-            axes.set_title(title)
             
-        # Save image array (with grid)
+        axes = self._annotate_plot(axes, annotate, title)            
         if save:
             path = _parse_path(save)
-            skimage.io.imsave(path, image)
-                        
-        return axes 
+            skimage.io.imsave(path, image)   
+        return axes
+
 
     def _draw_particles(self, image, force_binary=False):
         """ Draws particles over any image (ie background, background+grid.
@@ -653,19 +697,20 @@ class Canvas(HasTraits):
 
     @property
     def pout(self):
-        """ Returns all particles appearing FULLY outside the image"""
+        """ All particles appearing FULLY outside the image"""
         return self._particles[self._whereis('out')]    
 
 
     @property
     def pixcount(self):
-        """ Counts # pixels in image """
+        """ Image pixel count """
         l, w = self.rez
         return int(l * w)
+    
 
     @property
     def pixarea(self):
-        """ What's the best way to get this? """
+        """ Area white pixels in pbinary """
         return float(np.sum(self.pbinary)) / self.pixcount
 
     @property
@@ -805,7 +850,7 @@ class Canvas(HasTraits):
         # colorstring or hex
         elif isinstance(background, basestring):
             self._background = bgu.from_string(background, self.rx, self.ry)
-            self._bgstyle = 'file/colorstring'            
+            self._bgstyle = 'file/colorstring/url'            
 
         # If not array, color is assume as valid to_norm_rgb(color) arg
         # It will raise its own error if failure occurs
@@ -835,39 +880,53 @@ class Canvas(HasTraits):
     def __setitem__(self, key, particle):
         return self._particles.__setitem__(key, particles)
 
+
     def __getattr__(self, attr):
-        """ Defaults to particle manager """
+        """ Look for missing attributes on particle manager.
+        
+        Notes
+        -----
+        *args are NOT passed to called methods; kwargs are.  If absolutely
+        need ARGS, see how I handled add.  Could not get wrapper
+        to work correctly because it generally wanted to return a function
+        but sometimes this returns objects, lists etc... not just functions
+        so doing for example c.plist would try to give c.plist() and so on.
+        """
+        
         try:
-            return getattr(self._particles, attr)
+            return getattr(self._particles, attr)       
         except ParticleError:
             raise CanvasAttributeError('"%s" could not be found on %s, '
                 'underlying manager, or on one-or multiple of the '
-                'Particles' % (attr, self.__class__.__name__) )
+                'Particles' % (attr, self.__class__.__name__) )             
 
     def __iter__(self):
         """ Iteration is blocked """
         raise CanvasError("Iteration on canvas is ambiguous.  Iterate over "
                           "canvas.image or canvas.particles")
 
+    @property
+    def _address(self):
+        """ Property to make easily accesible by multicanvas """
+        return mem_address(super(Canvas, self).__repr__())
+        
+    
     def __repr__(self):
         _bgstyle = self._bgstyle #REPLACE
         res = '(%s X %s)' % (self.rx, self.ry ) 
-        address = mem_address(super(Canvas, self).__repr__())
         
         g=self.grid
         xd, yd = g.xdiv, g.ydiv 
         gridstring = "%sxygrid[%s] -->  (%sp X %sp) : (%.1f X %.1f) [pix/tile]" \
             % (_PAD, xd*yd, xd, yd, g.xspacing, g.yspacing)
-        
-                                                         # For sublcassing
-        outstring = "%s at %s:\n" % (self.__class__.__name__, address)
 
+        # MAY WANT TO USE COLUMN ALIGNMENT 
+
+        outstring = "%s (%s):\n" % (self.__class__.__name__, self._address)
         outstring += "%sbackground  -->  %s : %s\n" % (_PAD, res, _bgstyle) 
-
         outstring += "%sparticles   -->  %s particles : %s types\n" % (_PAD, \
             len(self._particles), len(self._particles.ptype_count))
-        outstring += gridstring
-        
+        outstring += gridstring        
         return outstring
 
     def __len__(self):
@@ -887,11 +946,40 @@ class Canvas(HasTraits):
     # Class methods
     # ------------
     @classmethod
-    def copy(cls, obj):
-        """ Returns a copied canvas object. """
-        newgrid = copy.copy(obj.grid)
-        return cls(background=obj.background, particles=obj._particles, 
-                        rez=obj.rez, grid=newgrid, _threshfcn=obj._threshfcn)        
+    def copy(cls, obj, grid=None, background=None, particles=None,
+             rez=None, _threshfcn = None):
+        """ Returns a copied canvas object.  __init__ params are taken from
+        object unless explicitly passed.  
+        
+        Notes
+        -----
+        copy grid, bg and particles separately as they are 
+        deep objects.  Particles is especially finiky so just
+        create a completely new instance of it.
+        
+        Explicit passing is useful, for insance, if one wants to copy a
+        canvas with new particles.  This makes the operation quicker than
+        copying the old particles and then overwriting.
+        """
+    
+        if not grid:
+            grid = copy.copy(obj.grid)
+        if not background:        
+            background = copy.copy(obj.background)
+        if not particles:
+            particles = ParticleManager(plist=obj.plist, copy=True)
+            
+        if not rez:
+            rez = obj.rez
+            
+        if not _threshfcn:
+            _threshfcn = obj.threshfcn
+        
+        return cls(background=background, 
+                   particles=particles, 
+                   rez=rez, 
+                   grid=grid, 
+                   _threshfcn=_threshfcn)        
 
     
     # Extend to polygons/other partciles in future
@@ -900,22 +988,46 @@ class Canvas(HasTraits):
     def random_circles(cls, n=50, rmin=5, rmax=50, background=BGCOLOR, pcolor=None):
         """ Return a canvas populated with n randomly positioned circles.  
         Radius ranges vary randomly between 5 and 50."""
-        import random as r
+        from random import randint as RIT
                        
         particles = ParticleManager()            
         # Randomize particle centers within the image default dimensions
         for i in range(n):
-            cx, cy = r.randint(0, BGRES[0]), r.randint(0, BGRES[1])
-            radius = r.randint(rmin,rmax)
+            cx, cy = RIT(0, BGRES[0]), RIT(0, BGRES[1])
+            radius = RIT(rmin,rmax)
             particles.add('circle', center=(cx,cy), radius=radius, 
                           color=to_normrgb(pcolor))
         
         # Use default resolution and grid
         return cls(background=background, particles=particles)
 
+    @classmethod
+    def random_triangles(cls, n=50, lmin=5, lmax=50, background=BGCOLOR, pcolor=None):
+        """ Return a canvas populated with n randomly positioned circles.  
+        Radius ranges vary randomly between 5 and 50."""
+        from random import randint as RIT
+                       
+        particles = ParticleManager()            
+        # Randomize particle centers within the image default dimensions
+        for i in range(n):
+            # ADD PADDING ADHOC AT THE MOMENT!!
+            PAD = 2*lmax
+            cx, cy = RIT(0+PAD, BGRES[0]-PAD), RIT(0+PAD, BGRES[1]-PAD)
+            length = RIT(lmin,lmax)
+            particles.add('triangle', center=(cx,cy), length=length, 
+                          color=to_normrgb(pcolor))
+        
+        # Use default resolution and grid
+        return cls(background=background, particles=particles)
+    
+    
 
 class ScaledCanvas(Canvas):
     """ Canvas with a "scale" that maps system of coordinates from pixels
         to pre-set units."""
     NotImplemented
-
+    
+    
+if __name__ == '__main__':
+    c=Canvas()
+    print 'hi'
\ No newline at end of file
