@@ -198,23 +198,36 @@ class ParticleManager(HasTraits):
    
     @cached_property
     def _get__namemap(self):
-        """ Store light map of name to index for faster name lookup.  I verified
-            that this updates when plist elemnts are updated as well as obj itself.
-            """
+        """ Map name to index for faster name lookup.  I verified this 
+        updates when plist elemnts are updated as well as obj itself. """
         return dict( (pobj.name, idx) for idx, pobj in enumerate(self.plist))    
             
-    def add(self, particle, name='', color=None, force=False, *pargs, **pkwargs):
+
+    def add(self, particle, *pargs, **pkwargs):
         """ If color not passed, default color is used
             If not idx, put in last entry 
 
             Attributes
             ----------
             
-            *pargs : valid Particle constructor positionals
+            particle : Name of valid pyparty particle (eg 'circle')
+            
+            name : Particle name
+            
+            color : Str or None
+                Color of particle; defaults to Config specification
+            
+            force : Bool (False)
+                ???             
+            *pargs : Particle constructor args
+            
+            **pkwargs : Particle constructor kwargs
             """
+        
+        name = pkwargs.pop('name', '')
+        force = pkwargs.pop('force', False)
+        color = pkwargs.pop('color', None)  
      
-    
-        # Make particle from name and arguments
         if isinstance(particle, basestring):
             particle = self._make_particle(particle, *pargs, **pkwargs)
 
@@ -265,12 +278,15 @@ class ParticleManager(HasTraits):
         """ Apply a function to all particles.  Can also use functools.partial"""
         self.plist[:] = [fcn(p, *args, **kwargs) for p in self.plist]
         
+        
     def reverse(self):
         """ In place since list is inplace """
         self.plist.reverse()
+
     
     def pop(self, idx):
         self.plist.pop(idx)
+
     
     def idx(self, *names):
         """ Return index given names """
@@ -278,6 +294,7 @@ class ParticleManager(HasTraits):
         if len(out) == 1:
             out = out[0]
         return out
+
     
     def _unmask_index(self, idx):
         """ Test if object is an integer, string, or isntance of 
@@ -309,7 +326,7 @@ class ParticleManager(HasTraits):
         return self.plist.__iter__()
     
     def __getitem__(self, keyslice):
-        """ Supports single name lookup; otherwise defers to list delitem"""
+        """ Supports single name lookup; otherwise defers to list getitem"""
 
         if hasattr(keyslice, '__iter__'):
             # Boolean indexing
@@ -381,6 +398,11 @@ class ParticleManager(HasTraits):
             --------
             big_particles = p[p.perims > 50] """
         
+        # Bypasses a bug (or pyparty design flaw?) in ipython notebook 2.0 beta
+        # when ending a cell w/ c.particles
+        if attr == '_ipython_display_':
+            return         
+        
         out = tuple(getattr(p, attr) for p in self.plist)
         return np.array(out)
     
@@ -428,6 +450,13 @@ class ParticleManager(HasTraits):
         rr, cc = zip(*(p.rr_cc for p in self.plist))
         return ( np.concatenate(rr), np.concatenate(cc) )
         
+    def of_ptypes(self, *types):    
+        """ Keep plist of specified types.  Opted not to allow for inplace,
+        and implemented it at the Canvas level.
+        """
+        self.plist[:] = [p for p in self.plist if p.ptype in types]
+                
+        
     # Full attribute container sorted mappers        
     def sortby(self, attr='name', inplace=False, ascending=True):
         """ Sort list by attribute/descriptor"""
@@ -454,7 +483,7 @@ class ParticleManager(HasTraits):
     @property
     def ptypes(self):
         """ All UNIQUE particle types. """
-        return tuple(set( p.ptype for p in self.plist ) )
+        return tuple(sorted(set(p.ptype for p in self.plist)))
         
     @property
     def ptype_count(self):
